Module: Google::Apis::MybusinessverificationsV1
- Defined in:
- lib/google/apis/mybusinessverifications_v1.rb,
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/service.rb,
lib/google/apis/mybusinessverifications_v1/gem_version.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
My Business Verifications API
The My Business Verifications API provides an interface for taking verifications related actions for locations.
Defined Under Namespace
Classes: AddressVerificationData, CompleteVerificationRequest, CompleteVerificationResponse, ComplyWithGuidelines, EmailVerificationData, FetchVerificationOptionsRequest, FetchVerificationOptionsResponse, GenerateInstantVerificationTokenRequest, GenerateInstantVerificationTokenResponse, ListVerificationsResponse, MyBusinessVerificationsService, PostalAddress, ResolveOwnershipConflict, ServiceBusinessContext, Verification, VerificationOption, VerificationToken, Verify, VerifyLocationRequest, VerifyLocationResponse, VoiceOfMerchantState, WaitForVoiceOfMerchant
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-mybusinessverifications_v1 gem
"0.24.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260527"- VERSION =
Version of the My Business Verifications API this client connects to. This is NOT the gem version.
'V1'