Class: Google::Apis::MybusinessverificationsV1::CompleteVerificationResponse
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::CompleteVerificationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Response message for Verifications.CompleteVerificationAction.
Instance Attribute Summary collapse
-
#verification ⇒ Google::Apis::MybusinessverificationsV1::Verification
A verification represents a verification attempt on a location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompleteVerificationResponse
constructor
A new instance of CompleteVerificationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompleteVerificationResponse
Returns a new instance of CompleteVerificationResponse.
94 95 96 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 94 def initialize(**args) update!(**args) end |
Instance Attribute Details
#verification ⇒ Google::Apis::MybusinessverificationsV1::Verification
A verification represents a verification attempt on a location.
Corresponds to the JSON property verification
92 93 94 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 92 def verification @verification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
99 100 101 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 99 def update!(**args) @verification = args[:verification] if args.key?(:verification) end |