Class: Google::Apis::MybusinessverificationsV1::ComplyWithGuidelines

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

Indicates that the location fails to comply with our guidelines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComplyWithGuidelines

Returns a new instance of ComplyWithGuidelines.



114
115
116
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendation_reasonString

The reason why the location is being recommended to comply with guidelines. Corresponds to the JSON property recommendationReason

Returns:

  • (String)


112
113
114
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 112

def recommendation_reason
  @recommendation_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



119
120
121
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 119

def update!(**args)
  @recommendation_reason = args[:recommendation_reason] if args.key?(:recommendation_reason)
end