Class: Google::Apis::MybusinessverificationsV1::EmailVerificationData
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::EmailVerificationData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Display data for verifications through email.
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain name in the email address.
-
#is_user_name_editable ⇒ Boolean
(also: #is_user_name_editable?)
Whether client is allowed to provide a different user name.
-
#user ⇒ String
User name in the email address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmailVerificationData
constructor
A new instance of EmailVerificationData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmailVerificationData
Returns a new instance of EmailVerificationData.
144 145 146 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Domain name in the email address. e.g. "gmail.com" in foo@gmail.com
Corresponds to the JSON property domain
131 132 133 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 131 def domain @domain end |
#is_user_name_editable ⇒ Boolean Also known as: is_user_name_editable?
Whether client is allowed to provide a different user name.
Corresponds to the JSON property isUserNameEditable
136 137 138 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 136 def is_user_name_editable @is_user_name_editable end |
#user ⇒ String
User name in the email address. e.g. "foo" in foo@gmail.com
Corresponds to the JSON property user
142 143 144 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 142 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
149 150 151 152 153 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 149 def update!(**args) @domain = args[:domain] if args.key?(:domain) @is_user_name_editable = args[:is_user_name_editable] if args.key?(:is_user_name_editable) @user = args[:user] if args.key?(:user) end |