Class: Google::Apis::MybusinessverificationsV1::LocationData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

The address and other details of the location to generate an instant verification token for.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationData

Returns a new instance of LocationData.



320
321
322
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressGoogle::Apis::MybusinessverificationsV1::PostalAddress

Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/ libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/ answer/6397478. Corresponds to the JSON property address



304
305
306
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 304

def address
  @address
end

#nameString

Immutable. Name should reflect your business's real-world name, as used consistently on your storefront, website, and stationery, and as known to customers. Any additional information, when relevant, can be included in other fields of the resource (for example, Address, Categories). Don't add unnecessary information to your name (for example, prefer "Google" over " Google Inc. - Mountain View Corporate Headquarters"). Don't include marketing taglines, store codes, special characters, hours or closed/open status, phone numbers, website URLs, service/product information, location/address or directions, or containment information (for example, "Chase ATM in Duane Reade" ). Corresponds to the JSON property name

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 318

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



325
326
327
328
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 325

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @name = args[:name] if args.key?(:name)
end