Class: Google::Apis::MybusinessverificationsV1::Verification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

A verification represents a verification attempt on a location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Verification

Returns a new instance of Verification.



486
487
488
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#announcementString

Optional. Response announcement set only if the method is VETTED_PARTNER. Corresponds to the JSON property announcement

Returns:

  • (String)


464
465
466
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 464

def announcement
  @announcement
end

#create_timeString

The timestamp when the verification is requested. Corresponds to the JSON property createTime

Returns:

  • (String)


469
470
471
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 469

def create_time
  @create_time
end

#method_propString

The method of the verification. Corresponds to the JSON property method

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 474

def method_prop
  @method_prop
end

#nameString

Resource name of the verification. Corresponds to the JSON property name

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 479

def name
  @name
end

#stateString

The state of the verification. Corresponds to the JSON property state

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 484

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



491
492
493
494
495
496
497
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 491

def update!(**args)
  @announcement = args[:announcement] if args.key?(:announcement)
  @create_time = args[:create_time] if args.key?(:create_time)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end