Class: Google::Apis::MybusinessverificationsV1::VerificationOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

The verification option represents how to verify the location (indicated by verification method) and where the verification will be sent to (indicated by display data).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerificationOption

Returns a new instance of VerificationOption.



532
533
534
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_dataGoogle::Apis::MybusinessverificationsV1::AddressVerificationData

Display data for verifications through postcard. Corresponds to the JSON property addressData



509
510
511
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 509

def address_data
  @address_data
end

#announcementString

Set only if the method is VETTED_PARTNER. Corresponds to the JSON property announcement

Returns:

  • (String)


514
515
516
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 514

def announcement
  @announcement
end

#email_dataGoogle::Apis::MybusinessverificationsV1::EmailVerificationData

Display data for verifications through email. Corresponds to the JSON property emailData



519
520
521
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 519

def email_data
  @email_data
end

#phone_numberString

Set only if the method is PHONE_CALL or SMS. Phone number that the PIN will be sent to. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 525

def phone_number
  @phone_number
end

#verification_methodString

Method to verify the location. Corresponds to the JSON property verificationMethod

Returns:

  • (String)


530
531
532
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 530

def verification_method
  @verification_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



537
538
539
540
541
542
543
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 537

def update!(**args)
  @address_data = args[:address_data] if args.key?(:address_data)
  @announcement = args[:announcement] if args.key?(:announcement)
  @email_data = args[:email_data] if args.key?(:email_data)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @verification_method = args[:verification_method] if args.key?(:verification_method)
end