Class: Google::Apis::MybusinessverificationsV1::Verify

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

Indicates that the location requires verification. Contains information about the current verification actions performed on the location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Verify

Returns a new instance of Verify.



578
579
580
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_pending_verificationBoolean Also known as: has_pending_verification?

Indicates whether a verification process has already started, and can be completed by the location. Corresponds to the JSON property hasPendingVerification

Returns:

  • (Boolean)


575
576
577
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 575

def has_pending_verification
  @has_pending_verification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



583
584
585
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 583

def update!(**args)
  @has_pending_verification = args[:has_pending_verification] if args.key?(:has_pending_verification)
end