Class: Google::Apis::MybusinessverificationsV1::VerifyLocationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

Request message for Verifications.VerifyLocation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerifyLocationRequest

Returns a new instance of VerifyLocationRequest.



642
643
644
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextGoogle::Apis::MybusinessverificationsV1::ServiceBusinessContext

Additional data for service business verification. Corresponds to the JSON property context



595
596
597
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 595

def context
  @context
end

#email_addressString

Optional. The input for EMAIL method. Email address where the PIN should be sent to. An email address is accepted only if it is one of the addresses provided by FetchVerificationOptions. If the EmailVerificationData has is_user_name_editable set to true, the client may specify a different user name (local-part) but must match the domain name. Corresponds to the JSON property emailAddress

Returns:

  • (String)


604
605
606
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 604

def email_address
  @email_address
end

#language_codeString

Optional. The BCP 47 language code representing the language that is to be used for the verification process. Corresponds to the JSON property languageCode

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 610

def language_code
  @language_code
end

#mailer_contactString

Optional. The input for ADDRESS method. Contact name the mail should be sent to. Corresponds to the JSON property mailerContact

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 616

def mailer_contact
  @mailer_contact
end

#method_propString

Required. Verification method. Corresponds to the JSON property method

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 621

def method_prop
  @method_prop
end

#phone_numberString

Optional. The input for PHONE_CALL/SMS method The phone number that should be called or be sent SMS to. It must be one of the phone numbers in the eligible options. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


628
629
630
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 628

def phone_number
  @phone_number
end

#tokenGoogle::Apis::MybusinessverificationsV1::VerificationToken

Token generated by a vetted partner. Corresponds to the JSON property token



634
635
636
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 634

def token
  @token
end

#trusted_partner_tokenString

The input for TRUSTED_PARTNER method The verification token that is associated to the location. Corresponds to the JSON property trustedPartnerToken

Returns:

  • (String)


640
641
642
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 640

def trusted_partner_token
  @trusted_partner_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



647
648
649
650
651
652
653
654
655
656
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 647

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @email_address = args[:email_address] if args.key?(:email_address)
  @language_code = args[:language_code] if args.key?(:language_code)
  @mailer_contact = args[:mailer_contact] if args.key?(:mailer_contact)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @token = args[:token] if args.key?(:token)
  @trusted_partner_token = args[:trusted_partner_token] if args.key?(:trusted_partner_token)
end