Class: Google::Apis::MybusinessverificationsV1::VerifyLocationResponse
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::VerifyLocationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Response message for Verifications.VerifyLocation.
Instance Attribute Summary collapse
-
#verification ⇒ Google::Apis::MybusinessverificationsV1::Verification
A verification represents a verification attempt on a location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VerifyLocationResponse
constructor
A new instance of VerifyLocationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VerifyLocationResponse
Returns a new instance of VerifyLocationResponse.
668 669 670 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#verification ⇒ Google::Apis::MybusinessverificationsV1::Verification
A verification represents a verification attempt on a location.
Corresponds to the JSON property verification
666 667 668 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 666 def verification @verification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
673 674 675 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 673 def update!(**args) @verification = args[:verification] if args.key?(:verification) end |