Class: Google::Apis::MybusinessverificationsV1::VoiceOfMerchantState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

Response message for VoiceOfMerchant.GetVoiceOfMerchantState.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoiceOfMerchantState

Returns a new instance of VoiceOfMerchantState.



722
723
724
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comply_with_guidelinesGoogle::Apis::MybusinessverificationsV1::ComplyWithGuidelines

Indicates that the location fails to comply with our guidelines. Corresponds to the JSON property complyWithGuidelines



686
687
688
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 686

def comply_with_guidelines
  @comply_with_guidelines
end

#has_business_authorityBoolean Also known as: has_business_authority?

Indicates whether the location has the authority (ownership) over the business on Google. If true, another location cannot take over and become the dominant listing on Maps. However, edits will not become live unless Voice of Merchant is gained (i.e. has_voice_of_merchant is true). Corresponds to the JSON property hasBusinessAuthority

Returns:

  • (Boolean)


694
695
696
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 694

def has_business_authority
  @has_business_authority
end

#has_voice_of_merchantBoolean Also known as: has_voice_of_merchant?

Indicates whether the location is in good standing and has control over the business on Google. Any edits made to the location will propagate to Maps after passing the review phase. Corresponds to the JSON property hasVoiceOfMerchant

Returns:

  • (Boolean)


702
703
704
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 702

def has_voice_of_merchant
  @has_voice_of_merchant
end

#resolve_ownership_conflictGoogle::Apis::MybusinessverificationsV1::ResolveOwnershipConflict

Indicates that the location duplicates another location that is in good standing. Corresponds to the JSON property resolveOwnershipConflict



709
710
711
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 709

def resolve_ownership_conflict
  @resolve_ownership_conflict
end

#verifyGoogle::Apis::MybusinessverificationsV1::Verify

Indicates that the location requires verification. Contains information about the current verification actions performed on the location. Corresponds to the JSON property verify



715
716
717
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 715

def verify
  @verify
end

#wait_for_voice_of_merchantGoogle::Apis::MybusinessverificationsV1::WaitForVoiceOfMerchant

Indicates that the location will gain voice of merchant after passing review. Corresponds to the JSON property waitForVoiceOfMerchant



720
721
722
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 720

def wait_for_voice_of_merchant
  @wait_for_voice_of_merchant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



727
728
729
730
731
732
733
734
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 727

def update!(**args)
  @comply_with_guidelines = args[:comply_with_guidelines] if args.key?(:comply_with_guidelines)
  @has_business_authority = args[:has_business_authority] if args.key?(:has_business_authority)
  @has_voice_of_merchant = args[:has_voice_of_merchant] if args.key?(:has_voice_of_merchant)
  @resolve_ownership_conflict = args[:resolve_ownership_conflict] if args.key?(:resolve_ownership_conflict)
  @verify = args[:verify] if args.key?(:verify)
  @wait_for_voice_of_merchant = args[:wait_for_voice_of_merchant] if args.key?(:wait_for_voice_of_merchant)
end