Class: Google::Apis::MybusinessverificationsV1::AddressVerificationData
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::AddressVerificationData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Display data for verifications through postcard.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::MybusinessverificationsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#business ⇒ String
Merchant's business name.
-
#expected_delivery_days_region ⇒ Fixnum
Expected number of days it takes to deliver a postcard to the address's region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddressVerificationData
constructor
A new instance of AddressVerificationData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddressVerificationData
Returns a new instance of AddressVerificationData.
54 55 56 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 54 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::MybusinessverificationsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property address
42 43 44 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 42 def address @address end |
#business ⇒ String
Merchant's business name.
Corresponds to the JSON property business
47 48 49 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 47 def business @business end |
#expected_delivery_days_region ⇒ Fixnum
Expected number of days it takes to deliver a postcard to the address's region.
Corresponds to the JSON property expectedDeliveryDaysRegion
52 53 54 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 52 def expected_delivery_days_region @expected_delivery_days_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59 60 61 62 63 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 59 def update!(**args) @address = args[:address] if args.key?(:address) @business = args[:business] if args.key?(:business) @expected_delivery_days_region = args[:expected_delivery_days_region] if args.key?(:expected_delivery_days_region) end |