Class: Google::Apis::MybusinessverificationsV1::GenerateInstantVerificationTokenRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

Request message for Verifications.GenerateInstantVerificationToken.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateInstantVerificationTokenRequest

Returns a new instance of GenerateInstantVerificationTokenRequest.



222
223
224
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_dataGoogle::Apis::MybusinessverificationsV1::LocationData

The address and other details of the location to generate an instant verification token for. Corresponds to the JSON property locationData



209
210
211
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 209

def location_data
  @location_data
end

#location_idString

The location identifier associated with an unverified listing. This is the location id generated at the time that the listing was originally created. It is the final portion of a location resource name as generated by the Google My Business API. Note: the caller must be an owner or manager of this listing in order to generate a verification token. See the location resource documentation for more information. Corresponds to the JSON property locationId

Returns:

  • (String)


220
221
222
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 220

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



227
228
229
230
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 227

def update!(**args)
  @location_data = args[:location_data] if args.key?(:location_data)
  @location_id = args[:location_id] if args.key?(:location_id)
end