Class: Google::Apis::MybusinessverificationsV1::ServiceBusinessContext
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::ServiceBusinessContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Additional data for service business verification.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::MybusinessverificationsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceBusinessContext
constructor
A new instance of ServiceBusinessContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceBusinessContext
Returns a new instance of ServiceBusinessContext.
499 500 501 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::MybusinessverificationsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property address
497 498 499 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 497 def address @address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
504 505 506 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 504 def update!(**args) @address = args[:address] if args.key?(:address) end |