Class: Google::Apis::MybusinessverificationsV1::VerificationOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb

Overview

The verification option represents how to verify the location (indicated by verification method) and where the verification will be sent to (indicated by display data).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerificationOption

Returns a new instance of VerificationOption.



584
585
586
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_dataGoogle::Apis::MybusinessverificationsV1::AddressVerificationData

Display data for verifications through postcard. Corresponds to the JSON property addressData



561
562
563
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 561

def address_data
  @address_data
end

#announcementString

Set only if the method is VETTED_PARTNER. Corresponds to the JSON property announcement

Returns:

  • (String)


566
567
568
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 566

def announcement
  @announcement
end

#email_dataGoogle::Apis::MybusinessverificationsV1::EmailVerificationData

Display data for verifications through email. Corresponds to the JSON property emailData



571
572
573
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 571

def email_data
  @email_data
end

#phone_numberString

Set only if the method is PHONE_CALL or SMS. Phone number that the PIN will be sent to. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


577
578
579
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 577

def phone_number
  @phone_number
end

#verification_methodString

Method to verify the location. Corresponds to the JSON property verificationMethod

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 582

def verification_method
  @verification_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



589
590
591
592
593
594
595
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 589

def update!(**args)
  @address_data = args[:address_data] if args.key?(:address_data)
  @announcement = args[:announcement] if args.key?(:announcement)
  @email_data = args[:email_data] if args.key?(:email_data)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @verification_method = args[:verification_method] if args.key?(:verification_method)
end