Class: Google::Apis::MybusinessverificationsV1::VerifyLocationRequest
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessverificationsV1::VerifyLocationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessverifications_v1/classes.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb,
lib/google/apis/mybusinessverifications_v1/representations.rb
Overview
Request message for Verifications.VerifyLocation.
Instance Attribute Summary collapse
-
#context ⇒ Google::Apis::MybusinessverificationsV1::ServiceBusinessContext
Additional data for service business verification.
-
#email_address ⇒ String
Optional.
-
#language_code ⇒ String
Optional.
-
#mailer_contact ⇒ String
Optional.
-
#method_prop ⇒ String
Required.
-
#phone_number ⇒ String
Optional.
-
#token ⇒ Google::Apis::MybusinessverificationsV1::VerificationToken
Token generated by a vetted partner.
-
#trusted_partner_token ⇒ String
The input for TRUSTED_PARTNER method The verification token that is associated to the location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VerifyLocationRequest
constructor
A new instance of VerifyLocationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VerifyLocationRequest
Returns a new instance of VerifyLocationRequest.
694 695 696 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ Google::Apis::MybusinessverificationsV1::ServiceBusinessContext
Additional data for service business verification.
Corresponds to the JSON property context
647 648 649 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 647 def context @context end |
#email_address ⇒ String
Optional. The input for EMAIL method. Email address where the PIN should be
sent to. An email address is accepted only if it is one of the addresses
provided by FetchVerificationOptions. If the EmailVerificationData has
is_user_name_editable set to true, the client may specify a different user
name (local-part) but must match the domain name.
Corresponds to the JSON property emailAddress
656 657 658 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 656 def email_address @email_address end |
#language_code ⇒ String
Optional. The BCP 47 language code representing the language that is to be
used for the verification process.
Corresponds to the JSON property languageCode
662 663 664 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 662 def language_code @language_code end |
#mailer_contact ⇒ String
Optional. The input for ADDRESS method. Contact name the mail should be sent
to.
Corresponds to the JSON property mailerContact
668 669 670 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 668 def mailer_contact @mailer_contact end |
#method_prop ⇒ String
Required. Verification method.
Corresponds to the JSON property method
673 674 675 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 673 def method_prop @method_prop end |
#phone_number ⇒ String
Optional. The input for PHONE_CALL/SMS method The phone number that should be
called or be sent SMS to. It must be one of the phone numbers in the eligible
options.
Corresponds to the JSON property phoneNumber
680 681 682 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 680 def phone_number @phone_number end |
#token ⇒ Google::Apis::MybusinessverificationsV1::VerificationToken
Token generated by a vetted partner.
Corresponds to the JSON property token
686 687 688 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 686 def token @token end |
#trusted_partner_token ⇒ String
The input for TRUSTED_PARTNER method The verification token that is associated
to the location.
Corresponds to the JSON property trustedPartnerToken
692 693 694 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 692 def trusted_partner_token @trusted_partner_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
699 700 701 702 703 704 705 706 707 708 |
# File 'lib/google/apis/mybusinessverifications_v1/classes.rb', line 699 def update!(**args) @context = args[:context] if args.key?(:context) @email_address = args[:email_address] if args.key?(:email_address) @language_code = args[:language_code] if args.key?(:language_code) @mailer_contact = args[:mailer_contact] if args.key?(:mailer_contact) @method_prop = args[:method_prop] if args.key?(:method_prop) @phone_number = args[:phone_number] if args.key?(:phone_number) @token = args[:token] if args.key?(:token) @trusted_partner_token = args[:trusted_partner_token] if args.key?(:trusted_partner_token) end |